@@ -619,6 +619,28 @@ def test_version_runs_build_command(
         "GITEA_ACTIONS": "true",
         "BITBUCKET_REPO_FULL_NAME": "python-semantic-release/python-semantic-release.git",
         "PSR_DOCKER_GITHUB_ACTION": "true",
+        # Windows
+        "ALLUSERSAPPDATA": "C:\\ProgramData",
+        "ALLUSERSPROFILE": "C:\\ProgramData",
+        "APPDATA": "C:\\Users\\Username\\AppData\\Roaming",
+        "COMMONPROGRAMFILES": "C:\\Program Files\\Common Files",
+        "COMMONPROGRAMFILES(x86)": "C:\\Program Files (x86)\\Common Files",
+        "DEFAULTUSERPROFILE": "C:\\Users\\Default",
+        "HOMEPATH": "\\Users\\Username",
+        "PATHEXT": ".COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH;.MSC",
+        "PROFILESFOLDER": "C:\\Users",
+        "PROGRAMFILES": "C:\\Program Files",
+        "PROGRAMFILES(x86)": "C:\\Program Files (x86)",
+        "SYSTEM": "C:\\Windows\\System32",
+        "SYSTEM16": "C:\\Windows\\System16",
+        "SYSTEM32": "C:\\Windows\\System32",
+        "SYSTEMDRIVE": "C:",
+        "SYSTEMROOT": "C:\\Windows",
+        "TEMP": "C:\\Users\\Username\\AppData\\Local\\Temp",
+        "TMP": "C:\\Users\\Username\\AppData\\Local\\Temp",
+        "USERPROFILE": "C:\\Users\\Username",
+        "USERSID": "S-1-5-21-1234567890-123456789-123456789-1234",
+        "WINDIR": "C:\\Windows",
     }
 
     # Mock out subprocess.run
@@ -626,7 +648,9 @@ def test_version_runs_build_command(
         "subprocess.run", return_value=CompletedProcess(args=(), returncode=0)
     ) as patched_subprocess_run, mock.patch(
         "shellingham.detect_shell", return_value=(exe, shell)
-    ), mock.patch.dict("os.environ", patched_os_environment, clear=True):
+    ), mock.patch("sys.platform", "linux"), mock.patch.dict(
+        "os.environ", patched_os_environment, clear=True
+    ):
         # ACT: run & force a new version that will trigger the build command
         result = cli_runner.invoke(
             main, [version_subcmd or "version", "--patch", "--no-push"]
@@ -653,6 +677,110 @@ def test_version_runs_build_command(
         )
 
 
+@pytest.mark.parametrize("shell", ("powershell", "cmd"))
+def test_version_runs_build_command_windows(
+    repo_with_git_flow_angular_commits: Repo,
+    cli_runner: CliRunner,
+    update_pyproject_toml: UpdatePyprojectTomlFn,
+    shell: str,
+):
+    # Setup
+    build_command = "bash -c \"echo 'hello world'\""
+    update_pyproject_toml("tool.semantic_release.build_command", build_command)
+    exe = shell.split("/")[-1]
+    patched_os_environment = {
+        "CI": "true",
+        "PATH": os.getenv("PATH"),
+        "HOME": os.getenv("HOME"),
+        "VIRTUAL_ENV": os.getenv("VIRTUAL_ENV", "./.venv"),
+        # Simulate that all CI's are set
+        "GITHUB_ACTIONS": "true",
+        "GITLAB_CI": "true",
+        "GITEA_ACTIONS": "true",
+        "BITBUCKET_REPO_FULL_NAME": "python-semantic-release/python-semantic-release.git",
+        "PSR_DOCKER_GITHUB_ACTION": "true",
+        # Windows
+        "ALLUSERSAPPDATA": "C:\\ProgramData",
+        "ALLUSERSPROFILE": "C:\\ProgramData",
+        "APPDATA": "C:\\Users\\Username\\AppData\\Roaming",
+        "COMMONPROGRAMFILES": "C:\\Program Files\\Common Files",
+        "COMMONPROGRAMFILES(x86)": "C:\\Program Files (x86)\\Common Files",
+        "DEFAULTUSERPROFILE": "C:\\Users\\Default",
+        "HOMEPATH": "\\Users\\Username",
+        "PATHEXT": ".COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH;.MSC",
+        "PROFILESFOLDER": "C:\\Users",
+        "PROGRAMFILES": "C:\\Program Files",
+        "PROGRAMFILES(x86)": "C:\\Program Files (x86)",
+        "SYSTEM": "C:\\Windows\\System32",
+        "SYSTEM16": "C:\\Windows\\System16",
+        "SYSTEM32": "C:\\Windows\\System32",
+        "SYSTEMDRIVE": "C:",
+        "SYSTEMROOT": "C:\\Windows",
+        "TEMP": "C:\\Users\\Username\\AppData\\Local\\Temp",
+        "TMP": "C:\\Users\\Username\\AppData\\Local\\Temp",
+        "USERPROFILE": "C:\\Users\\Username",
+        "USERSID": "S-1-5-21-1234567890-123456789-123456789-1234",
+        "WINDIR": "C:\\Windows",
+    }
+
+    # Mock out subprocess.run
+    with mock.patch(
+        "subprocess.run", return_value=CompletedProcess(args=(), returncode=0)
+    ) as patched_subprocess_run, mock.patch(
+        "shellingham.detect_shell", return_value=(exe, shell)
+    ), mock.patch("sys.platform", "win32"), mock.patch.dict(
+        "os.environ", patched_os_environment, clear=True
+    ):
+        # ACT: run & force a new version that will trigger the build command
+        result = cli_runner.invoke(
+            main, [version_subcmd or "version", "--patch", "--no-push"]
+        )
+        assert result.exit_code == 0
+
+        patched_subprocess_run.assert_called_once_with(
+            [exe, "-c" if shell != "cmd" else "/c", build_command],
+            check=True,
+            env={
+                "NEW_VERSION": "1.2.1",  # injected into environment
+                "CI": patched_os_environment["CI"],
+                "BITBUCKET_CI": "true",  # Converted
+                "GITHUB_ACTIONS": patched_os_environment["GITHUB_ACTIONS"],
+                "GITEA_ACTIONS": patched_os_environment["GITEA_ACTIONS"],
+                "GITLAB_CI": patched_os_environment["GITLAB_CI"],
+                "HOME": patched_os_environment["HOME"],
+                "PATH": patched_os_environment["PATH"],
+                "VIRTUAL_ENV": patched_os_environment["VIRTUAL_ENV"],
+                "PSR_DOCKER_GITHUB_ACTION": patched_os_environment[
+                    "PSR_DOCKER_GITHUB_ACTION"
+                ],
+                # Windows
+                "ALLUSERSAPPDATA": patched_os_environment["ALLUSERSAPPDATA"],
+                "ALLUSERSPROFILE": patched_os_environment["ALLUSERSPROFILE"],
+                "APPDATA": patched_os_environment["APPDATA"],
+                "COMMONPROGRAMFILES": patched_os_environment["COMMONPROGRAMFILES"],
+                "COMMONPROGRAMFILES(x86)": patched_os_environment[
+                    "COMMONPROGRAMFILES(x86)"
+                ],
+                "DEFAULTUSERPROFILE": patched_os_environment["DEFAULTUSERPROFILE"],
+                "HOMEPATH": patched_os_environment["HOMEPATH"],
+                "PATHEXT": patched_os_environment["PATHEXT"],
+                "PROFILESFOLDER": patched_os_environment["PROFILESFOLDER"],
+                "PROGRAMFILES": patched_os_environment["PROGRAMFILES"],
+                "PROGRAMFILES(x86)": patched_os_environment["PROGRAMFILES(x86)"],
+                "SYSTEM": patched_os_environment["SYSTEM"],
+                "SYSTEM16": patched_os_environment["SYSTEM16"],
+                "SYSTEM32": patched_os_environment["SYSTEM32"],
+                "SYSTEMDRIVE": patched_os_environment["SYSTEMDRIVE"],
+                "SYSTEMROOT": patched_os_environment["SYSTEMROOT"],
+                "TEMP": patched_os_environment["TEMP"],
+                "TMP": patched_os_environment["TMP"],
+                "USERPROFILE": patched_os_environment["USERPROFILE"],
+                "USERSID": patched_os_environment["USERSID"],
+                "WINDIR": patched_os_environment["WINDIR"],
+            },
+        )
+
+
 def test_version_runs_build_command_w_user_env(
     repo_with_git_flow_angular_commits: Repo,
     cli_runner: CliRunner,
